cmoncrawl.processor.pipeline.router.Router.load\_module\_as\_extractor
======================================================================

.. currentmodule:: cmoncrawl.processor.pipeline.router

.. automethod:: Router.load_module_as_extractor